==> claident-0.1.2013.03.14.zip: claident-0.1.2013.03.14/make_prokaryota_16S_genus.sh <==
# search by keywords at INSD
clretrievegi --keywords='"ddbj embl genbank"[Filter] AND ((txid2[Organism:exp] OR txid2157[Organism:exp]) AND 200:10000[Sequence Length] AND (16S[Title] AND ("ribosomal RNA"[Title] OR rRNA[Title] OR "ribosomal DNA"[Title] OR rDNA[Title])) NOT spacer[Title] NOT environmental[Title] NOT uncultured[Title] NOT unclassified[Title] NOT unidentified[Title] NOT pseudogene[Title])' prokaryota_16S.txt || exit $?
# make taxonomy database
clmaketaxdb --includetaxid=2,2157 taxonomy prokaryota.taxdb || exit $?
# extract genus-level identified sequences
clretrievegi --includetaxa=genus,.+ --gilist=prokaryota_16S.txt --taxdb=prokaryota.taxdb prokaryota_16S_genus.txt || exit $?
# extract species-level identified sequences
clretrievegi --includetaxa=genus,.+ --maxrank=species --ngword=' sp\.' --gilist=prokaryota_16S.txt --taxdb=prokaryota.taxdb prokaryota_16S_species.txt || exit $?
# make BLAST database
cd blastdb || exit $?
#blastdb_aliastool -dbtype nucl -db ./nt -gilist ../prokaryota_16S_genus.txt -out prokaryota_16S_genus -title prokaryota_16S_genus || exit $?
#blastdb_aliastool -dbtype nucl -db ./nt -gilist ../prokaryota_16S_species.txt -out prokaryota_16S_species -title prokaryota_16S_species || exit $?
blastdbcmd -db ./nt -target_only -entry_batch ../prokaryota_16S_genus.txt -out - | makeblastdb -in - -dbtype nucl -parse_seqids -hash_index -out prokaryota_16S_genus -title prokaryota_16S_genus || exit $?
blastdb_aliastool -dbtype nucl -db prokaryota_16S_genus -gilist ../prokaryota_16S_species.txt -out prokaryota_16S_species -title prokaryota_16S_species || exit $?
cd .. || exit $?
# minimize taxdb
clmaketaxdb --gilist=prokaryota_16S_genus.txt taxonomy prokaryota_16S_genus.taxdb || exit $?
ln -s prokaryota_16S_genus.taxdb prokaryota_16S_species.taxdb || exit $?

==> claident-0.1.2014.02.06.zip: claident-0.1.2014.02.06/make_prokaryota_16S_genus.sh <==
# search by keywords at INSD
clretrievegi --keywords='"ddbj embl genbank"[Filter] AND ((txid2[Organism:exp] OR txid2157[Organism:exp]) AND 200:10000[Sequence Length] AND (16S[Title] AND ("ribosomal RNA"[Title] OR rRNA[Title] OR "ribosomal DNA"[Title] OR rDNA[Title])) NOT spacer[Title] NOT environmental[Title] NOT uncultured[Title] NOT unclassified[Title] NOT unidentified[Title])' prokaryota_16S.txt || exit $?
# make taxonomy database
clmaketaxdb --includetaxid=2,2157 taxonomy prokaryota.taxdb || exit $?
# extract genus-level identified sequences
clretrievegi --includetaxa=genus,.+ --gilist=prokaryota_16S.txt --taxdb=prokaryota.taxdb prokaryota_16S_genus.txt || exit $?
# extract species-level identified sequences
clretrievegi --includetaxa=genus,.+ --maxrank=species --ngword=' sp\.' --gilist=prokaryota_16S.txt --taxdb=prokaryota.taxdb prokaryota_16S_species.txt || exit $?
# make BLAST database
cd blastdb || exit $?
#blastdb_aliastool -dbtype nucl -db ./nt -gilist ../prokaryota_16S_genus.txt -out prokaryota_16S_genus -title prokaryota_16S_genus || exit $?
#blastdb_aliastool -dbtype nucl -db ./nt -gilist ../prokaryota_16S_species.txt -out prokaryota_16S_species -title prokaryota_16S_species || exit $?
blastdbcmd -db ./nt -target_only -entry_batch ../prokaryota_16S_genus.txt -out - | makeblastdb -in - -dbtype nucl -parse_seqids -hash_index -out prokaryota_16S_genus -title prokaryota_16S_genus || exit $?
blastdb_aliastool -dbtype nucl -db prokaryota_16S_genus -gilist ../prokaryota_16S_species.txt -out prokaryota_16S_species -title prokaryota_16S_species || exit $?
cd .. || exit $?
# minimize taxdb
clmaketaxdb --gilist=prokaryota_16S_genus.txt taxonomy prokaryota_16S_genus.taxdb || exit $?
ln -s prokaryota_16S_genus.taxdb prokaryota_16S_species.taxdb || exit $?
